componenttools.copy_and_partition_governed_component_subtree_by_leaf_counts
===========================================================================

.. autofunction:: abjad.tools.componenttools.copy_and_partition_governed_component_subtree_by_leaf_counts.copy_and_partition_governed_component_subtree_by_leaf_counts
